cal.EventTypes (Calendar entry types) — amici1

# `cal.EventTypes` (Calendar entry types)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.CharField: ref>`

- `<django.db.models.fields.IntegerField: seqno>`

- `<lino.utils.mldbc.fields.BabelCharField: name>`

- `<django.db.models.fields.BooleanField: attach_to_email>`

- `<django.db.models.fields.CharField: email_template>`

- `<lino.core.fields.RichTextField: description>`

- `<django.db.models.fields.BooleanField: is_appointment>`

- `<django.db.models.fields.BooleanField: all_rooms>`

- `<django.db.models.fields.BooleanField: locks_user>`

- `<django.db.models.fields.BooleanField: force_guest_states>`

- `<django.db.models.fields.BooleanField: fill_presences>`

- `<django.db.models.fields.DateField: start_date>`

- `<lino.utils.mldbc.fields.BabelCharField: event_label>`

- `<django.db.models.fields.PositiveIntegerField: max_conflicting>`

- `<django.db.models.fields.PositiveIntegerField: max_days>`

- `<django.db.models.fields.BooleanField: transparent>`

- `<lino.core.choicelists.ChoiceListField: planner_column>`

- `<lino.core.fields.DurationField: default_duration>`

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.EventTypes>`

- `<Panel main_2 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.EventTypes>`

- `<Panel main_3 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.EventTypes>`

- `<Panel main_4 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.EventTypes>`

- `<Panel main_5 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.EventTypes>`

- `<GridElement EntriesByType in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.EventTypes>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Calendar entry type.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate this row.

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Merge (merge_row) : See `<lino.core.merge.MergeAction merge_row ('Merge')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (move_by_n) : Move this row N rows upwards or downwards.

- ▼ (move_down) : Exchange the seqno of this item and the next item.

- ▲ (move_up) : Exchange the seqno of this item and the previous item.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

## Filter parameters